%define scl rh-python36
%{?scl:%scl_package %{name}}
%{!?scl:%global pkg_name %{name}}

%define name azure-mgmt-cosmosdb
%define version 0.5.2
%define unmangled_version 0.5.2
%define unmangled_version 0.5.2
%define release 1

Summary: Microsoft Azure Cosmos DB Management Client Library for Python
%{?scl:Requires: %{scl}-runtime}
%{?scl:BuildRequires: %{scl}-runtime}
Name: %{?scl_prefix}azure-mgmt-cosmosdb
Version: %{version}
Release: %{release}
Source0: azure-mgmt-cosmosdb-%{unmangled_version}.zip
License: MIT License
Group: Development/Libraries
BuildRoot: %{_tmppath}/azure-mgmt-cosmosdb-%{version}-%{release}-buildroot
Prefix: %{_prefix}
BuildArch: noarch
Vendor: Microsoft Corporation <azpysdkhelp@microsoft.com>
Packager: Martin Juhl <m@rtinjuhl.dk>
Url: https://github.com/Azure/azure-sdk-for-python


%description
Microsoft Azure SDK for Python
==============================

This is the Microsoft Azure Cosmos DB Management Client Library.

Azure Resource Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.4, 3.5, 3.6 and 3.7.

For the older Azure Service Management (ASM) libraries, see
`azure-servicemanagement-legacy <https://pypi.python.org/pypi/azure-servicemanagement-legacy>`__ library.

For a more complete set of Azure libraries, see the `azure <https://pypi.python.org/pypi/azure>`__ bundle package.


Compatibility
=============

**IMPORTANT**: If you have an earlier version of the azure package
(version < 1.0), you should uninstall it before installing this package.

You can check the version using pip:

.. code:: shell

    pip freeze

If you see azure==0.11.0 (or any version below 1.0), uninstall it first:

.. code:: shell

    pip uninstall azure


Usage
=====

For code examples, see `Cosmos DB Management
<https://docs.microsoft.com/python/api/overview/azure/cosmosdb>`__
on docs.microsoft.com.


Provide Feedback
================

If you encounter any bugs or have suggestions, please file an issue in the
`Issues <https://github.com/Azure/azure-sdk-for-python/issues>`__
section of the project.


.. :changelog:

Release History
===============

0.5.2 (2018-11-05)
++++++++++++++++++

**Features**

- Add ignore_missing_vnet_service_endpoint support

0.5.1 (2018-10-16)
++++++++++++++++++

**Bugfix**

- Fix sdist broken in 0.5.0. No code change.

0.5.0 (2018-10-08)
++++++++++++++++++

**Features**

- Add enable_multiple_write_locations support

**Note**

- `database_accounts.list_read_only_keys` is now doing a POST call, and not GET anymore. This should not impact anything.
  Old behavior be can found with the `database_accounts.get_read_only_keys` **deprecated** method.
- azure-mgmt-nspkg is not installed anymore on Python 3 (PEP420-based namespace package)

0.4.1 (2018-05-15)
++++++++++++++++++

**Features**

- Add database_accounts.offline_region
- Add database_accounts.online_region
- Client class can be used as a context manager to keep the underlying HTTP session open for performance

0.4.0 (2018-04-17)
++++++++++++++++++

**General Breaking changes**

This version uses a next-generation code generator that *might* introduce breaking changes.

- Model signatures now use only keyword-argument syntax. All positional arguments must be re-written as keyword-arguments.
  To keep auto-completion in most cases, models are now generated for Python 2 and Python 3. Python 3 uses the "*" syntax for keyword-only arguments.
- Enum types now use the "str" mixin (class AzureEnum(str, Enum)) to improve the behavior when unrecognized enum values are encountered.
  While this is not a breaking change, the distinctions are important, and are documented here:
  https://docs.python.org/3/library/enum.html#others
  At a glance:

  - "is" should not be used at all.
  - "format" will return the string value, where "%s" string formatting will return `NameOfEnum.stringvalue`. Format syntax should be prefered.

- New Long Running Operation:

  - Return type changes from `msrestazure.azure_operation.AzureOperationPoller` to `msrest.polling.LROPoller`. External API is the same.
  - Return type is now **always** a `msrest.polling.LROPoller`, regardless of the optional parameters used.
  - The behavior has changed when using `raw=True`. Instead of returning the initial call result as `ClientRawResponse`,
    without polling, now this returns an LROPoller. After polling, the final resource will be returned as a `ClientRawResponse`.
  - New `polling` parameter. The default behavior is `Polling=True` which will poll using ARM algorithm. When `Polling=False`,
    the response of the initial call will be returned without polling.
  - `polling` parameter accepts instances of subclasses of `msrest.polling.PollingMethod`.
  - `add_done_callback` will no longer raise if called after polling is finished, but will instead execute the callback right away.

**Bugfixes**

- Compatibility of the sdist with wheel 0.31.0

**Features**

- Add VNet related properties to CosmosDB


0.3.1 (2018-02-01)
++++++++++++++++++

**Bugfixes**

- Fix capabilities model definition

0.3.0 (2018-01-30)
++++++++++++++++++

**Features**

- Add capability
- Add metrics operation groups

0.2.1 (2017-10-18)
++++++++++++++++++

**Bugfixes**

* Fix max_interval_in_seconds interval values from 1/100 to 5/86400
* Tags is now optional

**Features**

* Add operation list

0.2.0 (2017-06-26)
++++++++++++++++++

* Creation on this package based on azure-mgmt-documentdb 0.1.3 content



%prep
%{?scl:scl enable %{scl} - << \EOF}
set -ex
%setup -n azure-mgmt-cosmosdb-%{unmangled_version} -n azure-mgmt-cosmosdb-%{unmangled_version}
%{?scl:EOF}


%build
%{?scl:scl enable %{scl} - << \EOF}
set -ex
python3 setup.py build
%{?scl:EOF}


%install
%{?scl:scl enable %{scl} - << \EOF}
set -ex
python3 setup.py install --single-version-externally-managed -O1 --root=$RPM_BUILD_ROOT --record=INSTALLED_FILES
%{?scl:EOF}


%clean
%{?scl:scl enable %{scl} - << \EOF}
set -ex
rm -rf $RPM_BUILD_ROOT
%{?scl:EOF}


%files -f INSTALLED_FILES
%defattr(-,root,root)
